@@ -18,7 +18,7 @@ void doit( void )
 {
 	fptr func;
 
-	copy_shellcode(buf, SHELLCODE_RETURN);
+	copy_shellcode(buf);
 
 	/* Convert the pointer to a function pointer */
 	func = (fptr)&buf;
