@@ -1,4 +1,4 @@
-/* execheap.c - Tests wether code in the heap can be executed
+/* execheap.c - Tests whether code in the heap can be executed
  *
  * Copyright (c)2003 by Peter Busser <peter@adamantix.org>
  * This file has been released under the GNU Public Licence version 2 or later
@@ -8,22 +8,22 @@
 #include <string.h>
 #include <stdlib.h>
 #include "body.h"
+#include "shellcode.h"
 
-char *testname = "Executable heap                          ";
+const char testname[] = "Executable heap                          ";
 
 void doit( void )
 {
 	char *buf;
 	fptr func;
 
-	buf = malloc( 1 );
+	buf = malloc( MAX_SHELLCODE_LEN );
 	if( buf == NULL ) {
 		fprintf( stderr, "Out of memory\n" );
 		exit( 1 );
 	}
 
-	/* Put a RETN instruction in the buffer */
-	*buf = '\xc3';
+	copy_shellcode(buf);
 
 	/* Convert the pointer to a function pointer */
 	func = (fptr)buf;
@@ -34,4 +34,3 @@ void doit( void )
 	/* It worked when the function returns */
 	itworked();
 }
-
