@@ -10,7 +10,7 @@
 #include <sys/mman.h>
 
 
-#ifdef __OpenBSD__
+#ifndef MAP_ANONYMOUS
 #define MAP_ANONYMOUS MAP_ANON
 #endif
 
@@ -19,13 +19,12 @@ int main( int argc, char *argv[] )
 	char *buf;
 
 	buf = mmap(NULL, 4096, PROT_READ|PROT_WRITE, MAP_PRIVATE|MAP_ANONYMOUS, -1, 0);
-	if( buf == NULL ) {
+	if( buf == MAP_FAILED ) {
 		fprintf( stderr, "mmap() returned NULL\n" );
 		exit( 1 );
 	}
 
-	printf( "%0p\n", buf );
+	printf( "%p\n", buf );
 
 	exit( 0 );
 }
-
