@@ -1,4 +1,4 @@
-/* randamap.c - Tests the randomisation of anonymous mappings.
+/* randamap.c - Tests the randomization of anonymous mappings.
  * 
  * Copyright (c)2003 by Peter Busser <peter@adamantix.org>
  * This file has been released under the GNU Public Licence version 2 or later
@@ -8,6 +8,5 @@
 #error RUNDIR not defined
 #endif
 
-char *testname = "Anonymous mapping randomisation test     ";
-char *testprog = RUNDIR"/getamap";
-
+const char testname[] = "Anonymous mapping randomization test     ";
+const char testprog[] = RUNDIR"/getamap";
