@@ -1,4 +1,4 @@
-/* randmain1.c - Tests the randomisation of ET_EXEC main executable
+/* randmain1.c - Tests the randomization of ET_EXEC main executable
  * 
  * Copyright (c)2003 by Peter Busser <peter@adamantix.org>
  * This file has been released under the GNU Public Licence version 2 or later
@@ -8,5 +8,5 @@
 #error RUNDIR not defined
 #endif
 
-const char testname[] = "Main executable randomisation (ET_EXEC)  ";
+const char testname[] = "Main executable randomization (ET_EXEC)  ";
 const char testprog[] = RUNDIR"/getmain1";
