@@ -1,4 +1,4 @@
-/* randmain2.c - Tests the randomisation of the ET_DYN main executable
+/* randmain2.c - Tests the randomization of the ET_DYN main executable
  * 
  * Copyright (c)2003 by Peter Busser <peter@adamantix.org>
  * This file has been released under the GNU Public Licence version 2 or later
@@ -8,5 +8,5 @@
 #error RUNDIR not defined
 #endif
 
-const char testname[] = "Main executable randomisation (PIE)      ";
+const char testname[] = "Main executable randomization (PIE)      ";
 const char testprog[] = RUNDIR"/getmain2";
