@@ -4,11 +4,11 @@
  * This file has been released under the GNU Public Licence version 2 or later
  */
 
-#include "shellcode.h"
+#include "paxtest.h"
 
-char shbss2[4096];
+char shbss2[PAGE_SIZE_MAX] __pagealigned;
 
-char shdata2[4096] = SHELLCODE_RETURN_ARRAY;
+char shdata2[PAGE_SIZE_MAX] __pagealigned = { 'A' };
 
 /* A function which does nothing, it only exists so it can be referenced */
 int shlibtest2( void )
